==> haskell-hgmp-0.1.2.1-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hgmp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hgmp
version:              0.1.2.1
visibility:           public
id:                   hgmp-0.1.2.1-6fixHkdcy1s3XJJACtdoUs
key:                  hgmp-0.1.2.1-6fixHkdcy1s3XJJACtdoUs
license:              BSD-3-Clause
copyright:            2016,2017 Claude Heiland-Allen
maintainer:           claude@mathr.co.uk
author:               Claude Heiland-Allen
homepage:             https://code.mathr.co.uk/hgmp
synopsis:             Haskell interface to GMP
description:
    Types and instances, and marshalling between Integer and
    Rational and the corresponding GMP types, along with raw
    foreign imports of GMP functions.  Allows FFI to GMP code
    (whether in GMP itself or in third-party code that uses
    GMP).

    Supports only GHC with integer-gmp or ghc-bignum, this
    might change if there'\''s any demand.

category:             Numeric
abi:                  c54b046a89c4abebcae6c4035f5db927
exposed:              True
exposed-modules:
    Numeric.GMP.Raw.Safe Numeric.GMP.Raw.Unsafe Numeric.GMP.Types
    Numeric.GMP.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hgmp-0.1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hgmp-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hgmp
hs-libraries:         HShgmp-0.1.2.1-6fixHkdcy1s3XJJACtdoUs
depends:              base-4.16.4.0 ghc-bignum-1.2 ghc-prim-0.8.0
haddock-interfaces:   /usr/share/doc/haskell-hgmp/html/hgmp.haddock
haddock-html:         /usr/share/doc/haskell-hgmp/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hgmp-0.1.2.1-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hgmp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hgmp
version:              0.1.2.1
visibility:           public
id:                   hgmp-0.1.2.1-8c9LhnB0ntACxMPnktmpZP
key:                  hgmp-0.1.2.1-8c9LhnB0ntACxMPnktmpZP
license:              BSD-3-Clause
copyright:            2016,2017 Claude Heiland-Allen
maintainer:           claude@mathr.co.uk
author:               Claude Heiland-Allen
homepage:             https://code.mathr.co.uk/hgmp
synopsis:             Haskell interface to GMP
description:
    Types and instances, and marshalling between Integer and
    Rational and the corresponding GMP types, along with raw
    foreign imports of GMP functions.  Allows FFI to GMP code
    (whether in GMP itself or in third-party code that uses
    GMP).

    Supports only GHC with integer-gmp or ghc-bignum, this
    might change if there'\''s any demand.

category:             Numeric
abi:                  eb2f3d706026a50ca133ac8a845f1a90
exposed:              True
exposed-modules:
    Numeric.GMP.Raw.Safe Numeric.GMP.Raw.Unsafe Numeric.GMP.Types
    Numeric.GMP.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hgmp-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hgmp-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hgmp-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hgmp
hs-libraries:         HShgmp-0.1.2.1-8c9LhnB0ntACxMPnktmpZP
depends:              base-4.17.2.1 ghc-bignum-1.3 ghc-prim-0.9.1
haddock-interfaces:   /usr/share/doc/haskell-hgmp/html/hgmp.haddock
haddock-html:         /usr/share/doc/haskell-hgmp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
